/*
 * This file is generated by objective.metadata
 *
 * Last update: Thu Feb 15 21:33:39 2024
 */

static void __attribute__((__used__)) use_protocols(void)
{
    PyObject* p __attribute__((__unused__));
#if PyObjC_BUILD_RELEASE >= 1404
    p = PyObjC_IdToPython(@protocol(BEProcessCapabilityGrant)); Py_XDECREF(p);
    p = PyObjC_IdToPython(@protocol(BETextInputDelegate)); Py_XDECREF(p);
    p = PyObjC_IdToPython(@protocol(BETextInteractionDelegate)); Py_XDECREF(p);
#endif /* PyObjC_BUILD_RELEASE >= 1404 */
#if PyObjC_BUILD_RELEASE >= 1502
    // Not exposed on macOS
    //p = PyObjC_IdToPython(@protocol(BEAccessibilityTextMarker)); Py_XDECREF(p);
#endif /* PyObjC_BUILD_RELEASE >= 1502 */
}
